v11.utils
=========

.. _onebot_v11_check:

检查/验证
--------------------

.. autoclass:: melobot.protocols.onebot.v11.utils.LevelRole
    :exclude-members: __new__

.. autoclass:: melobot.protocols.onebot.v11.utils.GroupRole
    :exclude-members: __new__

.. autofunction:: melobot.protocols.onebot.v11.utils.get_level_role
    
.. autofunction:: melobot.protocols.onebot.v11.utils.get_group_role

.. autoclass:: melobot.protocols.onebot.v11.utils.MsgChecker

.. autoclass:: melobot.protocols.onebot.v11.utils.GroupMsgChecker

.. autoclass:: melobot.protocols.onebot.v11.utils.PrivateMsgChecker

.. autoclass:: melobot.protocols.onebot.v11.utils.MsgCheckerFactory

.. autoclass:: melobot.protocols.onebot.v11.utils.AtMsgChecker
